## Version 0.6.0 (2025-07-03)
### 🎉 Maintenance of cube's sources

- Python 3.9.2 is now the minimum (included)
- Minimum version of CubicWeb is now 4.5.2 (included)
- Maximum version of CubicWeb is now 5 (included)

## Version 0.5.0 (2023-07-24)
### 🎉 New features

- run flynt on the code base to convert everything into f-strings
- upgrade CubicWeb version to 4

### 🤖 Continuous integration

- that tox option is now named allowlist_externals

## Version 0.4.0 (2023-03-02)
### 🎉 New features

- pkginfo: upgrade cubicweb to ">=3.38.0,<3.39.0"
- pkginfo: upgrade prometheus-client to ">=0.16.0,<0.17.0"
- run pyupgrade

### 🤖 Continuous integration

- gitlab-ci: use templates from a common repository

## Version 0.3.0 (2022-04-08)
### 🎉 New features

- setup.py: increase cubicweb max version to 3.37.x

## Version 0.2.0 (2022-04-05)
### 🎉 New features

- cube-doctor: add add-set-cubicweb-max-version
- setup.py: increase cubicweb max version to 3.35.x

### 📝 Documentation

- licence: update licence dates

## Version 0.1.5 (2021-08-25)
### 👷 Bug fixes

- views.py

## Version 0.1.4 (2021-05-12)
### 👷 Bug fixes

- setup.py

## Version 0.1.3 (2021-05-12)
### 👷 Bug fixes

- packaging: depend on cubicweb 3.27

## Version 0.1.2 (2021-05-11)

- packaging

## Version 0.1.1 (2021-05-11)
### 🤷 Various changes

- First working version